#[non_exhaustive]pub enum SerdeError {
TypeMismatch {
message: String,
},
MissingMember {
member_name: String,
},
UnknownMember {
member_name: String,
},
InvalidInput {
message: String,
},
UnsupportedOperation {
message: String,
},
WriteFailed {
message: String,
},
Custom {
message: String,
},
}Expand description
Error type for shape serialization and deserialization operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TypeMismatch
The data did not match the expected type described by the schema.
MissingMember
A required structure member was missing during deserialization.
UnknownMember
An unknown member was encountered during deserialization.
InvalidInput
The input data was malformed or invalid for the format.
UnsupportedOperation
The operation is not supported by this serializer or deserializer.
WriteFailed
An error occurred while writing output during serialization.
Custom
Catch-all for errors not covered by other variants.
Implementations