pub struct ShapeId { /* private fields */ }Expand description
A Smithy Shape ID.
Shape IDs uniquely identify shapes in a Smithy model.
fqnis"smithy.example#Foo"namespaceis"smithy.example"shape_nameis"Foo"
Implementations
Sourceimpl ShapeId
impl ShapeId
Sourcepub const fn from_static(
fqn: &'static str,
namespace: &'static str,
shape_name: &'static str,
) -> Self
pub const fn from_static( fqn: &'static str, namespace: &'static str, shape_name: &'static str, ) -> Self
Creates a ShapeId from a static string at compile time.
This is used for const initialization of prelude schemas.
Sourcepub fn new_from_parts(
namespace: impl Into<Cow<'static, str>>,
shape_name: impl Into<Cow<'static, str>>,
) -> Self
pub fn new_from_parts( namespace: impl Into<Cow<'static, str>>, shape_name: impl Into<Cow<'static, str>>, ) -> Self
Creates a new ShapeId from a namespace and a shape_name.
Examples
use aws_smithy_schema::ShapeId;
let shape_id = ShapeId::new("smithy.api#String");Sourcepub fn new_from_fqn(fqn: impl Into<Cow<'static, str>>) -> Option<Self>
pub fn new_from_fqn(fqn: impl Into<Cow<'static, str>>) -> Option<Self>
Creates a new ShapeId from a fully qualified name.
Sourcepub fn new(fqn: impl Into<Cow<'static, str>>) -> Self
pub fn new(fqn: impl Into<Cow<'static, str>>) -> Self
Creates a new ShapeId from a fully qualified name.
Sourcepub fn namespace(&self) -> &str
pub fn namespace(&self) -> &str
Returns the namespace portion of the ShapeId.
Examples
use aws_smithy_schema::ShapeId;
let shape_id = ShapeId::new("smithy.api#String");
assert_eq!(shape_id.namespace(), "smithy.api");Sourcepub fn shape_name(&self) -> &str
pub fn shape_name(&self) -> &str
Returns the shape name portion of the ShapeId.
Examples
use aws_smithy_schema::ShapeId;
let shape_id = ShapeId::new("smithy.api#String");
assert_eq!(shape_id.shape_name(), "String");Sourcepub fn member_name(&self) -> Option<&str>
pub fn member_name(&self) -> Option<&str>
Returns the member name if this is a member shape ID.
Examples
use aws_smithy_schema::ShapeId;
let shape_id = ShapeId::new("com.example#MyStruct$member");
assert_eq!(shape_id.member_name(), Some("member"));Trait Implementations
impl Eq for ShapeId
impl StructuralPartialEq for ShapeId